@@ -185,13 +185,6 @@ __attribute__((warn_unused_result)) static int initialize_functions() {
 	   It is initialized==0 only for the first time
 	   so should be !initialized==0 most of the time. */
 	if (__builtin_expect(!initialized, 0)) {
-		log_use_colors use_colors = log_get_use_colors_unresolved();
-		/* Temporarily disable auto detection, since ncurses calls fopen, which
-		 * leads to initialize_functions calling itself. */
-		if (use_colors == log_use_colors_auto) {
-			log_set_use_colors(log_use_colors_no);
-		}
-
 		initialized = 1;
 		origlibc_open = dlsym(RTLD_NEXT, "open");
 		origlibc_open64 = dlsym(RTLD_NEXT, "open64");
@@ -239,7 +232,6 @@ __attribute__((warn_unused_result)) static int initialize_functions() {
 			initialized = 2;
 			debug_cowdancer("Initialization successfully finished.");
 		}
-		log_set_use_colors(use_colors);
 	}
 	/*
      Wait until somebody else finishes his job
